/**
 * Cases where this differs from fast-xml-parser:
 *
 * 1. Mixing text with nested tags (does not occur in AWS REST XML).
 * <mixed-text> hello, <bold>world</bold>, how are you?</mixed-text>
 *
 * @internal
 */
export declare function parseXML(xmlString: string): any;
